@@ -37,16 +37,17 @@ class Script(ApiDto):
 
     def to_json(self):
         obj = {
-           "id": str(self.script_id), "name": str(self.name),
-           "description": str(self.description),
-           "canGeneratePlot": str(self.canGeneratePlot),
-           "canGenerateModel": str(self.canGenerateModel),
-           "canGenerateData": str(self.canGenerateData),
-           "status": str(self.status),
-           "needExactColumnNumbers": str(self.needExactColumnNumbers),
-           "needExactColumnNames": str(self.needExactColumnNames),
-           "inputColumns": json.dumps(list(self.inputColumns)),
-           "outputColumns": json.dumps(list(self.outputColumns))
+            "id": str(self.script_id),
+            "name": str(self.name),
+            "description": str(self.description),
+            "canGeneratePlot": str(self.canGeneratePlot),
+            "canGenerateModel": str(self.canGenerateModel),
+            "canGenerateData": str(self.canGenerateData),
+            "status": str(self.status),
+            "needExactColumnNumbers": str(self.needExactColumnNumbers),
+            "needExactColumnNames": str(self.needExactColumnNames),
+            "inputColumns": json.dumps(list(self.inputColumns)),
+            "outputColumns": json.dumps(list(self.outputColumns))
         }
         return obj
 
@@ -71,9 +72,9 @@ class Script(ApiDto):
         if "needExactColumnNames" in obj.keys():
             self.needExactColumnNames = bool(obj["needExactColumnNames"])
         if "inputColumns" in obj.keys():
-            self.inputColumns = obj["inputColumns"]
+            self.inputColumns = json.loads(obj["inputColumns"])
         if "outputColumns" in obj.keys():
-            self.outputColumns = obj["outputColumns"]
+            self.outputColumns = json.loads(obj["outputColumns"])
 
     def copy(self, myfunction):
         self.function = Function()
