@@ -293,20 +293,25 @@ class WizataDSAPIClient:
 
     def execute(self,
                 execution: Execution = None,
-                request:Request = None,
-                dataframe = None,
-                script = None,
-                ml_model = None,
-                isAnomalyDetection = False,
-                function = None
+                request: Request = None,
+                dataframe=None,
+                script=None,
+                ml_model=None,
+                isAnomalyDetection=False,
+                function=None
                 ) -> Execution:
         """
-        execute an execution configuration on the server
+        execute an experimentation on the server.
 
         :param execution: Execution to execute on the server with configuration (Request, Script, ML Model, ...)
+        :param request: Request to use to generate a dataframe
+        :param dataframe: dataframe to be used as input (pandas or DS API type)
+        :param script: Script to be executed (accept Script, string(id) or uuid)
+        :param ml_model: MLModel to be executed (accept MLModel, ml_model(id) or uuid)
+        :param isAnomalyDetection: set to true to execute automatic anomaly detection
+        :param function: set to name of a built-in function to execute it
         :return: Execution updated with expected content (Data, Anomalies, Plots, ML Models, ...)
         """
-
         # Prepare
         if execution is None:
             execution = Execution()
@@ -385,20 +390,65 @@ class WizataDSAPIClient:
         else:
             raise TypeError("Type not supported.")
 
-    def test(self, obj: Execution) -> Execution:
+    def test(self,
+             execution: Execution = None,
+             request: Request = None,
+             dataframe=None,
+             script=None,
+             ml_model=None,
+             detect_anomalies=False,
+             function=None
+             ) -> Execution:
         """
-        test an execution to validate the script used.
-        Do not store anything on the DS API but return full content.
+        test an experimentation on the server.
 
-        :param obj: Execution to test - must contain a dataframe or a query and a script
+        DO NOT STORE ANYTHING ON SERVER.
+
+        :param execution: Execution to execute on the server with configuration (Request, Script, ML Model, ...)
+        :param request: Request to use to generate a dataframe
+        :param dataframe: dataframe to be used as input (pandas or DS API type)
+        :param script: Script to be executed (accept Script, string(id) or uuid)
+        :param ml_model: MLModel to be executed (accept MLModel, ml_model(id) or uuid)
+        :param detect_anomalies: set to true to execute automatic anomaly detection
+        :param function: set to name of a built-in function to execute it
         :return: Execution updated with expected content (Data, Anomalies, Plots, ML Models, ...)
         """
-        if isinstance(obj, Execution):
-            if obj.script is None:
-                raise ValueError("Execution must contains at least a Script.")
+        # Prepare
+        if execution is None:
+            execution = Execution()
+        if request is not None:
+            execution.request = request
+        if dataframe is not None:
+            if isinstance(dataframe, pandas.DataFrame):
+                execution.dataframe = dataframe
+            elif isinstance(dataframe, DSDataFrame):
+                execution.input_ds_dataframe = dataframe
+        if script is not None:
+            if isinstance(script, uuid.UUID):
+                execution.script = Script(script)
+            elif isinstance(script, str):
+                execution.script = Script(uuid.UUID(script))
+            elif isinstance(script, Script):
+                execution.script = script
+        if ml_model is not None:
+            if isinstance(ml_model, uuid.UUID):
+                execution.ml_model = MLModel(ml_model)
+            elif isinstance(ml_model, str):
+                execution.ml_model = MLModel(uuid.UUID(ml_model))
+            elif isinstance(ml_model, MLModel):
+                execution.ml_model = ml_model
+        if detect_anomalies:
+            execution.isAnomalyDetection = True
+        if function is not None:
+            execution.function = function
+
+        # Execute
+        if isinstance(execution, Execution):
+            if execution.script is None and execution.ml_model is None:
+                raise ValueError("Execution must contains at least a Script or a Model")
             response = requests.post(self.__url() + "execute/test",
                                      headers=self.__header(),
-                                     data=json.dumps(obj.to_json(), cls=DSAPIEncoder))
+                                     data=json.dumps(execution.to_json(), cls=DSAPIEncoder))
             if response.status_code == 200:
                 return dill.loads(response.content)
             else:
